@@ -85,7 +85,7 @@ class GeoJSONProvider(BaseProvider):
                 fields[f] = {'type': 'string'}
             return fields
 
-    def _load(self, skip_geometry=None, select_properties=[]):
+    def _load(self, skip_geometry=None, properties=[], select_properties=[]):
         """Load and validate the source GeoJSON file
         at self.data
 
@@ -103,6 +103,12 @@ class GeoJSONProvider(BaseProvider):
 
         # Must be a FeatureCollection
         assert data['type'] == 'FeatureCollection'
+
+        # filter by properties if set
+        if properties:
+            data['features'] = [f for f in data['features'] if \
+                all([str(f['properties'][p[0]]) == str(p[1]) for p in properties])]  # noqa
+
         # All features must have ids, TODO must be unique strings
         for i in data['features']:
             if 'id' not in i and self.id_field in i['properties']:
@@ -116,7 +122,7 @@ class GeoJSONProvider(BaseProvider):
 
     def query(self, startindex=0, limit=10, resulttype='results',
               bbox=[], datetime_=None, properties=[], sortby=[],
-              select_properties=[], skip_geometry=False, q=None):
+              select_properties=[], skip_geometry=False, q=None, **kwargs):
         """
         query the provider
 
@@ -135,7 +141,7 @@ class GeoJSONProvider(BaseProvider):
         """
 
         # TODO filter by bbox without resorting to third-party libs
-        data = self._load(skip_geometry=skip_geometry,
+        data = self._load(skip_geometry=skip_geometry, properties=properties,
                           select_properties=select_properties)
 
         data['numberMatched'] = len(data['features'])
@@ -148,7 +154,7 @@ class GeoJSONProvider(BaseProvider):
 
         return data
 
-    def get(self, identifier):
+    def get(self, identifier, **kwargs):
         """
         query the provider by id
 
