@@ -72,23 +72,23 @@ class RasterioProvider(BaseProvider):
         """
 
         domainset = {
-            'type': 'DomainSetType',
+            'type': 'DomainSet',
             'generalGrid': {
-                'type': 'GeneralGridCoverageType',
+                'type': 'GeneralGridCoverage',
                 'srsName': self._coverage_properties['bbox_crs'],
                 'axisLabels': [
                     self._coverage_properties['x_axis_label'],
                     self._coverage_properties['y_axis_label']
                 ],
                 'axis': [{
-                    'type': 'RegularAxisType',
+                    'type': 'RegularAxis',
                     'axisLabel': self._coverage_properties['x_axis_label'],
                     'lowerBound': self._coverage_properties['bbox'][0],
                     'upperBound': self._coverage_properties['bbox'][2],
                     'uomLabel': self._coverage_properties['bbox_units'],
                     'resolution': self._coverage_properties['resx']
                 }, {
-                    'type': 'RegularAxisType',
+                    'type': 'RegularAxis',
                     'axisLabel': self._coverage_properties['y_axis_label'],
                     'lowerBound': self._coverage_properties['bbox'][1],
                     'upperBound': self._coverage_properties['bbox'][3],
@@ -96,16 +96,16 @@ class RasterioProvider(BaseProvider):
                     'resolution': self._coverage_properties['resy']
                 }],
                 'gridLimits': {
-                    'type': 'GridLimitsType',
+                    'type': 'GridLimits',
                     'srsName': 'http://www.opengis.net/def/crs/OGC/0/Index2D',
                     'axisLabels': ['i', 'j'],
                     'axis': [{
-                        'type': 'IndexAxisType',
+                        'type': 'IndexAxis',
                         'axisLabel': 'i',
                         'lowerBound': 0,
                         'upperBound': self._coverage_properties['width']
                     }, {
-                        'type': 'IndexAxisType',
+                        'type': 'IndexAxis',
                         'axisLabel': 'j',
                         'lowerBound': 0,
                         'upperBound': self._coverage_properties['height']
@@ -126,7 +126,7 @@ class RasterioProvider(BaseProvider):
         """
 
         rangetype = {
-            'type': 'DataRecordType',
+            'type': 'DataRecord',
             'field': []
         }
 
@@ -143,9 +143,11 @@ class RasterioProvider(BaseProvider):
 
             rangetype['field'].append({
                 'id': i,
-                'type': 'QuantityType',
+                'type': 'Quantity',
                 'name': name,
-                'definition': dtype,
+                'encodingInfo': {
+                    'dataType': 'http://www.opengis.net/def/dataType/OGC/0/{}'.format(dtype)  # noqa
+                },
                 'nodata': nodataval,
                 'uom': {
                     'id': 'http://www.opengis.net/def/uom/UCUM/{}'.format(
